"""Application configuration settings."""
from pathlib import Path
from typing import ClassVar

from pydantic_settings import BaseSettings

# Create database directory
DB_DIR = Path("/app") / "storage" / "db"
DB_DIR.mkdir(parents=True, exist_ok=True)


class Settings(BaseSettings):
    """Application settings."""
    PROJECT_NAME: str = "Task Manager API"
    PROJECT_DESCRIPTION: str = "A FastAPI-based Task Manager API"
    VERSION: str = "0.1.0"
    API_V1_STR: str = "/api/v1"

    # Database
    DB_DIR: ClassVar[Path] = DB_DIR
    SQLALCHEMY_DATABASE_URL: str = f"sqlite:///{DB_DIR}/db.sqlite"

    model_config = {
        "case_sensitive": True,
        "env_file": ".env",
    }


settings = Settings()